// SNMPAP.CPP
//
// Switch Agent Program
//
// Walter Schuller
// University of North Florida
//  
// Last updated May 97



#include "general.hpp"
#include "calls.hpp"



//**************************************************
// Center Window

void CenterWindow(HWND hwnd)
   {
   RECT rc;
   int cx, cy;

   GetWindowRect(hwnd, &rc);
   cx = GetSystemMetrics(SM_CXSCREEN);
   cy = GetSystemMetrics(SM_CYSCREEN);
   
   MoveWindow(hwnd, (cx - rc.right + rc.left) / 2, 
         (cy - rc.bottom + rc.top) / 2,
         rc.right - rc.left, rc.bottom - rc.top, TRUE);  
   }


//*************************************************************************
// Initialize Main Window.

BOOL MainWnd_OnInitDialog(HWND hwnd, HWND hwndFocus, LPARAM lParam)
   {                            
   PAPPVARS pav = (PAPPVARS) lParam;
   LOGFONT logfont;
   LPFNCTL3DSUBCLASSDLGEX lpfnCtl3dSubclassDlgEx;
   HINSTANCE hInst = GetWindowInstance(hwnd);
   	 
	// Enable dialog to use 3D controls.
	if ((HINSTANCE) HINSTANCE_ERROR != pav->hinstCtl3d)
		{
		lpfnCtl3dSubclassDlgEx = (LPFNCTL3DSUBCLASSDLGEX)
				GetProcAddress(pav->hinstCtl3d, "Ctl3dSubclassDlgEx");  
		if (lpfnCtl3dSubclassDlgEx)
			(*lpfnCtl3dSubclassDlgEx)(hwnd, 0xffff);		
		}

   CenterWindow(hwnd);          

   SetWindowLong(hwnd, GWL_LPAPPVARS, (LONG) (LPAPPVARS) pav);    
         
   pav->hfontNormal = (HFONT) SendMessage(GetDlgItem(hwnd,
         IDC_STATUS), WM_GETFONT, 0, 0);

   GetObject(pav->hfontNormal, sizeof(LOGFONT), (LPSTR) &logfont);

   logfont.lfWeight = FW_NORMAL;

   pav->hfontNormal = CreateFontIndirect(&logfont);

   SendDlgItemMessage(hwnd, IDC_STATUS, WM_SETFONT, 
         (WPARAM) pav->hfontNormal, 0);

   SetDlgItemText(hwnd, IDC_CMDRESPONSE, "NONE");
   SetDlgItemText(hwnd, IDC_CMDEXECUTED, "NONE");
   SetDlgItemText(hwnd, IDC_CMDRECEIVED, "NONE");

   pav->pSnmpAgent = new CSnmpAgent(GetWindowInstance(hwnd), hwnd);
   
   pav->pSnmpAgent->Connect(NULL, PT_NOFLAGS, NULL, IPPORT_SNMP);

   return FALSE;
   }


//*************************************************************************
// Process WM_COMMAND Messages from Main Window.

void MainWnd_OnCommand(HWND hwnd, int id, HWND hwndCtl, UINT codeNotify)
   {  
   switch (id)
      {       

      case IDC_TESTBUTTON:      
		  {
// Test the Datacomm Port
         
			Ccontrol ctl; 
				
			ctl.Switch1();
			delay(1);
			ctl.Switch2();
			delay(1);
			ctl.Switch3();
			delay(1);
			ctl.Switch4();
			delay(1);
			ctl.Switch5();
			delay(1);
			ctl.Switch6();
			delay(1);
			ctl.Switch7();
			delay(1);
			ctl.Switch8();
			delay(1);
		
         break; 
		  }

//-------------------------------------------------------------------- 

      case IDC_ABOUT:      
		  {
// Display the ABOUT Dialog Box

       		AboutDlg_Do(hwnd, "SNMP C++/16 Class Library");
        	
        	break; 
		  }
	  
      }  

   }


//*************************************************************************
// Post a WM_QUIT Message and Set the Exit Code to 0.

void MainWnd_OnDestroy(HWND hwnd)
   {
   PAPPVARS pav = (PAPPVARS) GetWindowLong(hwnd, GWL_LPAPPVARS);

   DeleteObject(pav->hfontNormal);

   if (PT_CLOSED != pav->pSnmpAgent->State())
      pav->pSnmpAgent->Close(TRUE);

   delete pav->pSnmpAgent;

   PostQuitMessage(0);  
   }


//*************************************************************************
// Set the background color of buttons and static controls to light gray.

HBRUSH MainWnd_OnCtlColor(HWND hwnd, HDC hdc, HWND hwndChild, int type)
   {
   if (CTLCOLOR_BTN == type || CTLCOLOR_STATIC == type)           
      {                                       
      SetBkMode(hdc, TRANSPARENT);                                               
      return GetStockBrush(LTGRAY_BRUSH);
      }  
   
   return NULL;
   }


//*************************************************************************
// Process Main Window Messages

LRESULT CALLBACK MainWnd_WndProc(HWND hwnd, UINT msg, WPARAM wParam, 
      LPARAM lParam)
   { 
   switch(msg)                     
      {                 
      HANDLE_MSG(hwnd, WM_INITDIALOG, MainWnd_OnInitDialog);   
      HANDLE_MSG(hwnd, WM_COMMAND, MainWnd_OnCommand);   
      HANDLE_MSG(hwnd, WM_DESTROY, MainWnd_OnDestroy);
      
		#ifdef WIN32
      	HANDLE_MSG(hwnd, WM_CTLCOLORBTN, MainWnd_OnCtlColor);
      	HANDLE_MSG(hwnd, WM_CTLCOLORSTATIC, MainWnd_OnCtlColor);
		#else
      	HANDLE_MSG(hwnd, WM_CTLCOLOR, MainWnd_OnCtlColor);
		#endif
      }
   
   return DefWindowProc(hwnd, msg, wParam, lParam);
   }                                                                 


//*************************************************************************
// Initialize Application and Establish Message Loop.

int PASCAL WinMain(HINSTANCE hinstCurrent, HINSTANCE hinstPrevious,
      LPSTR lpszCmdLine, int nCmdShow)
   {
   WNDCLASS wndclass;
   HWND hwnd;
   MSG msg;                
   APPVARS av;
   LPFNCTL3DREGISTER lpfnCtl3dRegister;
   LPFNCTL3DAUTOSUBCLASS lpfnCtl3dAutoSubclass;
   
   av.szAppName = "SNMPA";
                                       
	#ifdef WIN32
		av.hinstCtl3d = LoadLibrary("CTL3D32.DLL");
	#else
		av.hinstCtl3d = LoadLibrary("CTL3DV2.DLL");
		if (av.hinstCtl3d < (HINSTANCE) HINSTANCE_ERROR)
			av.hinstCtl3d = LoadLibrary("CTL3D.DLL");
	#endif
	
	if (av.hinstCtl3d >= (HINSTANCE) HINSTANCE_ERROR)
		{  
		lpfnCtl3dRegister = (LPFNCTL3DREGISTER)
				GetProcAddress(av.hinstCtl3d, "Ctl3dRegister");  
		if (lpfnCtl3dRegister)	
			(*lpfnCtl3dRegister)(hinstCurrent);	

		lpfnCtl3dAutoSubclass = (LPFNCTL3DAUTOSUBCLASS)
				GetProcAddress(av.hinstCtl3d, "Ctl3dAutoSubclass");  
		if (lpfnCtl3dAutoSubclass)	
			(*lpfnCtl3dAutoSubclass)(hinstCurrent);	
		}

// Register Main Window Class
   if (!hinstPrevious)
      {
      wndclass.style          = CS_HREDRAW | CS_VREDRAW;
      wndclass.lpfnWndProc    = MainWnd_WndProc;
      wndclass.cbClsExtra     = 0;
      wndclass.cbWndExtra     = MAINWNDEXTRA;
      wndclass.hInstance      = hinstCurrent;
      wndclass.hIcon          = LoadIcon(hinstCurrent, "MAINICON");
      wndclass.hCursor        = LoadCursor(NULL, IDC_ARROW);
      wndclass.hbrBackground  = GetStockBrush(LTGRAY_BRUSH); 
      wndclass.lpszMenuName   = NULL;
      wndclass.lpszClassName  = av.szAppName;    

      RegisterClass(&wndclass);
      }

// Create Main Window.
   hwnd = CreateDialogParam(hinstCurrent, av.szAppName, 0, 
         (DLGPROC) MainWnd_WndProc, (LPARAM) (LPAPPVARS) &av);
   ShowWindow(hwnd, nCmdShow);
                                              
// Get and Dispatch Messages 
   while (GetMessage(&msg, NULL, 0, 0))
      if (!IsDialogMessage(hwnd, &msg))
         {
         TranslateMessage(&msg);
         DispatchMessage(&msg);
         }
   
   if (av.hinstCtl3d >= (HINSTANCE) HINSTANCE_ERROR)
		{
		LPFNCTL3DUNREGISTER lpfnCtl3dUnregister;
			
		lpfnCtl3dUnregister = (LPFNCTL3DREGISTER)
				GetProcAddress(av.hinstCtl3d, "Ctl3dUnregister");  
		if (lpfnCtl3dUnregister)	
			(*lpfnCtl3dUnregister)(hinstCurrent);	
		FreeLibrary(av.hinstCtl3d); 
		}

   return msg.wParam;
   }
      
//*************************************************************************
// END OF FILE                            WALT SCHULLER
