// Cagent.cpp

// Declaration of the Agent Class Functions
// Walter Schuller
// University of North Florida
// 
// Sony Tape Machine Agent
// 
// Last updated March 96
//
//           
//		SNMP Object Types: 
//
//		SNMP_INTEGER 		0X02	VALUE LONG
//		SNMP_OCTET_STRING	0X04	STRING
//		SNMP_NULL			0X05	VALUE LONG
//		SNMP_OBJECT_ID		0X06 	STRING DOT NOTATION
//		SNMP_IPADDRESS		0X40 	STRING DOT NOTATION
//		SNMP_COUNTER32		0X41	VALUE
//		SNMP_GAUGE32		0X42	VALUE
//		SNMP_TIMETICKS		0X43	VALUE
//		SNMP_QPAQUE			0X44	STRING
//		SNMP_UINTEGER32		0X47	VALUE
		
		
                                                                      
//*************************************************************************

#include "general.hpp"
#include "calls.hpp"

//*************************************************************************


CSnmpAgent::CSnmpAgent(HINSTANCE hinst, HWND hwnd) :
      CPowerSnmp(hinst), hwndMain(hwnd)
   {
   
   }
   

//*************************************************************************
// A UDP port has been successfully allocated.

void CSnmpAgent::ConnectSnmpEvent(LPCSTR lpszLocalDotAddr, WORD wLocalPort, 
      LPCSTR lpszLocalName, WORD wMaxByteCnt)
   {
   char szStatus[128];
   
   _fstrcpy(szLocalDotAddr, lpszLocalDotAddr);
   wsprintf(szStatus, "Listening on port %d.  MaxPacketSize = %d",
         wLocalPort, wMaxByteCnt);
  
   SetDlgItemText(hwndMain, IDC_STATUS, szStatus);   
   }
 
   
//*************************************************************************
// Process Received SNMP Messages.

void CSnmpAgent::RecvSnmpEvent(LPCSTR lpszCommunity, DWORD dwRequestId, 
      SNMP_ERROR codeSnmpError, int nErrorIndex, SNMP_TYPE MessageType, 
      UINT nObjects, LPSTR FAR* lpObjectId, LONG FAR* lpObjectValue, 
      SNMP_OBJECT_TYPE FAR* lpObjectType, LPCSTR lpszRemoteDotAddr,
      WORD wRemotePort)
   {
   SNMP_OBJECT_TYPE fObjectType = SNMP_OCTET_STRING;
   
   UINT i;
   HINSTANCE hinst = GetWindowInstance(hwndMain);
   
   Ccontrol 	ctl;
   
   char	*ptrsz;
   
   codeSnmpError = SNMP_NO_ERROR;

//-----------------------------------------------------------------------
// SNMP GET REQUEST Type Message

   switch (MessageType)
      {

      case SNMP_GET_REQUEST:  

         lpObjectValue = (LONG FAR*) GlobalAllocPtr(GPTR, nObjects * sizeof(LONG));  
         lpObjectType = (SNMP_OBJECT_TYPE FAR*) 
               GlobalAllocPtr(GPTR, nObjects * sizeof(SNMP_OBJECT_TYPE FAR*));
         
                  
         for (i = 0; i < nObjects; ++i)
            {
            if (IsEqual(hinst, IDS_SonyTimecode, lpObjectId[i]))
               {

   			   SetDlgItemText(hwndMain, IDC_CMDRECEIVED, "GET TIMECODE");
  			   SetDlgItemText(hwndMain, IDC_CMDEXECUTED, "SEND TIMECODE");
               
               ctl.Sony_time(); 
               ptrsz = ctl.RxBuf;

               SetDlgItemText(hwndMain, IDC_CMDRESPONSE, ptrsz);
               
             
               lpObjectValue[i] = GetStringProvided(ptrsz);           

               lpObjectType[i] = SNMP_OCTET_STRING; 
               
               
               
               }

            }         

         SendGetResponse(lpszRemoteDotAddr, wRemotePort, lpszCommunity, 
               dwRequestId, codeSnmpError, nErrorIndex, nObjects, 
               lpObjectId, lpObjectValue, lpObjectType);
         GlobalFreePtr(lpObjectValue);
         GlobalFreePtr(lpObjectType);
         break; 

//---------------------------------------------------------------------
//  SNMP SET REQUEST Type Message
      
       case SNMP_SET_REQUEST:
         
         for (i = 0; i < nObjects; ++i)
            {
            if (IsEqual(hinst, IDS_SonyPlay, lpObjectId[i])) 
            	{
  			   	SetDlgItemText(hwndMain, IDC_CMDEXECUTED, "START PLAY");
   			   	SetDlgItemText(hwndMain, IDC_CMDRECEIVED, "SET PLAY");
               	SetDlgItemText(hwndMain, IDC_CMDRESPONSE, "COMPLETE");

				ctl.Sony_play();
           		}

            else if (IsEqual(hinst, IDS_SonyStop, lpObjectId[i])) 
            	{
  			   	SetDlgItemText(hwndMain, IDC_CMDEXECUTED, "STOP TAPE");
   			   	SetDlgItemText(hwndMain, IDC_CMDRECEIVED, "SET STOP");
               	SetDlgItemText(hwndMain, IDC_CMDRESPONSE, "COMPLETE");

				ctl.Sony_stop();
            	}

            else if (IsEqual(hinst, IDS_SonyReverse, lpObjectId[i])) 
            	{
  			   	SetDlgItemText(hwndMain, IDC_CMDEXECUTED, "START TAPE REVERSE");
   			   	SetDlgItemText(hwndMain, IDC_CMDRECEIVED, "SET REVERSE");
               	SetDlgItemText(hwndMain, IDC_CMDRESPONSE, "COMPLETE");

				ctl.Sony_rewind();
            	}

            else if (IsEqual(hinst, IDS_SonyForward, lpObjectId[i])) 
            	{
  			   	SetDlgItemText(hwndMain, IDC_CMDEXECUTED, "START TAPE FORWARD");
   			   	SetDlgItemText(hwndMain, IDC_CMDRECEIVED, "SET FORWARD");
               	SetDlgItemText(hwndMain, IDC_CMDRESPONSE, "COMPLETE");

				ctl.Sony_forward();
            	}

            else if (IsEqual(hinst, IDS_SonyEject, lpObjectId[i])) 
            	{
  			   	SetDlgItemText(hwndMain, IDC_CMDEXECUTED, "EJECT TAPE");
   			   	SetDlgItemText(hwndMain, IDC_CMDRECEIVED, "SET EJECT");
               	SetDlgItemText(hwndMain, IDC_CMDRESPONSE, "COMPLETE");

				ctl.Sony_eject();
            	}

            else if (IsEqual(hinst, IDS_SonyRecord, lpObjectId[i])) 
            	{
  			   	SetDlgItemText(hwndMain, IDC_CMDEXECUTED, "START RECORD");
   			   	SetDlgItemText(hwndMain, IDC_CMDRECEIVED, "SET RECORD");
               	SetDlgItemText(hwndMain, IDC_CMDRESPONSE, "COMPLETE");

				ctl.Sony_record();
            	}

            }

         SendGetResponse(lpszRemoteDotAddr, wRemotePort, lpszCommunity, 
               dwRequestId, SNMP_NO_ERROR, 0, nObjects, lpObjectId, 
               lpObjectValue, lpObjectType);
         break; 
         
      }
      
   }
   
   
//*************************************************************************
// Display Error Message

void CSnmpAgent::ExceptionEvent(PT_EXCEPTION codeError, 
      LPCSTR lpszErrorDesc)    
   {                                               
   SetDlgItemText(hwndMain, IDC_STATUS, lpszErrorDesc);   
   }
   

//*************************************************************************
//  END OF FILE                              WALT SCHULLER
