// Ccontrol.cpp
//
// Class made from the MarshallSoft toolkit
// Used to control Sony Tape Machines
// 
// Walter Schuller
// University of North Florida
//  
// Last updated March 97


#include "general.hpp"
#include "calls.hpp"
 
// Sony Tape Control Command Strings

 int sony_who[]         =  {3,0x00,0x11,0x11};
 int sony_enable[]      =  {3,0x00,0x1d,0x1d};
 int sony_play[]        =  {3,0x20,0x01,0x21};
 int sony_time[]        =  {4,0x61,0x0c,0x01,0x6e};
 int sony_stop[]        =  {3,0x20,0x00,0x20};
 int sony_rewind[]      =  {3,0x20,0x20,0x40};
 int sony_forward[]     =  {3,0x20,0x10,0x30};
 int sony_eject[]       =  {3,0x20,0x0f,0x2f};
 int sony_stdby_on[]    =  {3,0x20,0x05,0x25};
 int sony_stdby_off[]   =  {3,0x20,0x04,0x24};
 int sony_record[]      =  {3,0x20,0x02,0x22};
 int sony_status[]      =  {4,0x61,0x20,0x2a,0x08};
 int sony_auto_edit[]   =  {3,0x20,0x42,0x62};
 int sony_edit_on[]     =  {3,0x20,0x65,0x85};
 int sony_edit_off[]    =  {3,0x20,0x64,0x84};
 int sony_in_entry[]    =  {3,0x40,0x10,0x50};
 int sony_tab_plus[]    =  {3,0x40,0x18,0x58};
 int sony_in_reset[]    =  {3,0x40,0x20,0x60};
 int sony_out_reset[]   =  {3,0x40,0x21,0x61};
 int sony_set_edit[]    =  {4,0x41,0x30,0x50,0xc1};
 int sony_ain_reset[]   =  {3,0x40,0x22,0x62};
 int sony_aout_reset[]  =  {3,0x40,0x23,0x63};
 int sony_reset_edit[]  =  {4,0x41,0x30,0x00,0x71};
 int sony_preroll[]     =  {3,0x20,0x30,0x50};
 int sony_auto_on[]     =  {3,0x40,0x41,0x81};
 int sony_auto_off[]    =  {3,0x40,0x40,0x80};
 
//*****************************************************************
// Constructor

Ccontrol::Ccontrol(int v, int w, int x, int y, int z)
	{ 
	Port=v;
	BaudCode=w;
	Parity=x;
	StopBits=y;
	DataBits=z;
	             
//	SioReset(COM1, 128, 128);
//	SioRxClear(COM1); 
//	SioParms(COM1, OddParity, OneStopBit, WordLength8);
//	SioBaud(COM1, Baud38400);
	
	SioReset(Port, 128, 128);
    SioRxClear(Port);
	SioParms(Port, Parity, StopBits, DataBits);
	SioBaud(Port,BaudCode);  
	
	}
	


//*****************************************************************
// Destructor

Ccontrol::~Ccontrol()
	{
	SioDone(Port); 
	MessageBeep(-10);
	}
	

//*****************************************************************
// Part of Send Command

 int Ccontrol::send_cmd(int *cmdptr)
 {
	 int i=0, num, count = 0;
	 num = *cmdptr;
	 for (count=1;count<num+1;count++)
		{
//		delay(0.1);
		SioPutc(Port,*(cmdptr + count));
		}
	
	 return 0;
 }


//*****************************************************************
// SONY PLAY Command

void Ccontrol::Sony_play()
	{
	send_cmd(sony_play);
	}

	
//*****************************************************************
// SONY STOP Command

void Ccontrol::Sony_stop()
	{
	send_cmd(sony_stop);
	}
	

 
//*****************************************************************
// SONY REWIND Command

void Ccontrol::Sony_rewind()
	{
	send_cmd(sony_rewind);
	}
	


//*****************************************************************
// SONY FORWARD Command

void Ccontrol::Sony_forward()
	{
	send_cmd(sony_forward);
	}

 
//*****************************************************************
// SONY EJECT Command

void Ccontrol::Sony_eject()
	{
	send_cmd(sony_eject);
	}


//*****************************************************************
// SONY RECORD Command

void Ccontrol::Sony_record()
	{
	send_cmd(sony_record);
	}
 
 
//*****************************************************************
// SONY GET TIMECODE Command

//     returned data
//    ---------------
// 74 04 52 15 1 0 f0  version requires the modification of frame field
//       F  S  M F      drop frame
//     -40H

// 74 04 12 15 1 0 f0  other version requires no modification of frame field
//       F  S  M F      non-drop frame

// assume drop frame tape format


void Ccontrol::Sony_time()
	{                                    
	int i, count=0, drop_frame;
    char hours[20], mins[20], secs[20], frams[20];
    
	_fstrcpy(time_buffer,"                             ");

//	SioRxClear(COM1); 
	SioRxClear(Port); 					/* clear port */
		
	send_cmd(sony_time); 	

//	delay(0.5);
//	while(SioRxQue(COM1)<5) {}; 	   
	while(SioRxQue(Port)<5) {}; 	   /* wait for return message */
	
		
	  do
		  { 							/* get chars from buffer */
		  delay(0.3);
		  i = SioGetc(Port);
		  if (i > -1) *(time_buffer+count) = i;
		  count++;
		  }
	  while(i > -1);
      
	  *(time_buffer+count) = '\0';

	  if (*(time_buffer+2)&0x40)
			{
			*(time_buffer+2)-=0x40;     /* correct for dropframe */

			drop_frame=TRUE;
			}
	  else
			drop_frame=FALSE;

	  count=2;

//     convert time to integer and write results to RxBuf

	   do
		  {
			if      (*(time_buffer+count) > 0x09 && *(time_buffer+count) < 0x20) *(time_buffer+count)-=6;          
			else if (*(time_buffer+count) > 0x19 && *(time_buffer+count) < 0x30) *(time_buffer+count)-=12;
			else if (*(time_buffer+count) > 0x29 && *(time_buffer+count) < 0x40) *(time_buffer+count)-=18;
			else if (*(time_buffer+count) > 0x39 && *(time_buffer+count) < 0x50) *(time_buffer+count)-=24;
			else if (*(time_buffer+count) > 0x49 && *(time_buffer+count) < 0x60) *(time_buffer+count)-=30;
			else if (*(time_buffer+count) > 0x59) *(time_buffer+count)=60;
			count++;
		  }
	   while (count < 6);
       
       _itoa(*(time_buffer+5), hours, 10);
       _itoa(*(time_buffer+4), mins,  10);
       _itoa(*(time_buffer+3), secs,  10);
       _itoa(*(time_buffer+2), frams, 10);
	   
	   _fstrcpy(RxBuf,"  TimeCode = ");
	   _fstrcat(RxBuf,hours);
	   _fstrcat(RxBuf,":");
	   _fstrcat(RxBuf,mins);
	   _fstrcat(RxBuf,":");
	   _fstrcat(RxBuf,secs);
	   _fstrcat(RxBuf,":");
	   _fstrcat(RxBuf,frams);
	   
	   
	 };


//*****************************************************************
// END OF FILE                        WALT SCHULLER
