// Cagent.cpp

// Declaration of the Agent Class Functions
// Walter Schuller
// University of North Florida
//  
// Last updated March 96
//
//           
//		SNMP Object Types: 
//
//		SNMP_INTEGER 		0X02	VALUE LONG
//		SNMP_OCTET_STRING	0X04	STRING
//		SNMP_NULL			0X05	VALUE LONG
//		SNMP_OBJECT_ID		0X06 	STRING DOT NOTATION
//		SNMP_IPADDRESS		0X40 	STRING DOT NOTATION
//		SNMP_COUNTER32		0X41	VALUE
//		SNMP_GAUGE32		0X42	VALUE
//		SNMP_TIMETICKS		0X43	VALUE
//		SNMP_QPAQUE			0X44	STRING
//		SNMP_UINTEGER32		0X47	VALUE
		
		
                                                                      
//*************************************************************************

#include "general.hpp"
#include "calls.hpp"

//*************************************************************************


CSnmpAgent::CSnmpAgent(HINSTANCE hinst, HWND hwnd) :
      CPowerSnmp(hinst), hwndMain(hwnd)
   {
   
   }
   

//*************************************************************************
// A UDP port has been successfully allocated.

void CSnmpAgent::ConnectSnmpEvent(LPCSTR lpszLocalDotAddr, WORD wLocalPort, 
      LPCSTR lpszLocalName, WORD wMaxByteCnt)
   {
   char szStatus[128];
   
   _fstrcpy(szLocalDotAddr, lpszLocalDotAddr);
   wsprintf(szStatus, "Listening on port %d.  MaxPacketSize = %d",
         wLocalPort, wMaxByteCnt);
  
   SetDlgItemText(hwndMain, IDC_STATUS, szStatus);   
   }
 
   
//*************************************************************************
// Process Received SNMP Messages.

void CSnmpAgent::RecvSnmpEvent(LPCSTR lpszCommunity, DWORD dwRequestId, 
      SNMP_ERROR codeSnmpError, int nErrorIndex, SNMP_TYPE MessageType, 
      UINT nObjects, LPSTR FAR* lpObjectId, LONG FAR* lpObjectValue, 
      SNMP_OBJECT_TYPE FAR* lpObjectType, LPCSTR lpszRemoteDotAddr,
      WORD wRemotePort)
   {
   SNMP_OBJECT_TYPE fObjectType = SNMP_OCTET_STRING;
   
   UINT i;
   HINSTANCE hinst = GetWindowInstance(hwndMain);
   
   Ccontrol 	ctl;
   int			data;
   
   codeSnmpError = SNMP_NO_ERROR;

//-----------------------------------------------------------------------
// SNMP GET REQUEST Type Message

   switch (MessageType)
      {

      case SNMP_GET_REQUEST:  

         lpObjectValue = (LONG FAR*) GlobalAllocPtr(GPTR, nObjects * sizeof(LONG));  
         lpObjectType = (SNMP_OBJECT_TYPE FAR*) 
               GlobalAllocPtr(GPTR, nObjects * sizeof(SNMP_OBJECT_TYPE FAR*));
         
                  
         for (i = 0; i < nObjects; ++i)
            {
            if (IsEqual(hinst, IDS_TxVisPwr, lpObjectId[i]))
               {

   			   SetDlgItemText(hwndMain, IDC_CMDRECEIVED, "GET VISUAL PWR");
  			   SetDlgItemText(hwndMain, IDC_CMDEXECUTED, "SEND POWER");
               
               data = ctl.Get_VisPwr();
               
               lpObjectValue[i] = data;              
               lpObjectType[i] = SNMP_INTEGER; 
               
               SetDlgItemInt(hwndMain, IDC_CMDRESPONSE, data, TRUE);

               }

            else if (IsEqual(hinst, IDS_TxAurPwr, lpObjectId[i]))
               {

   			   SetDlgItemText(hwndMain, IDC_CMDRECEIVED, "GET AURAL PWR");
  			   SetDlgItemText(hwndMain, IDC_CMDEXECUTED, "SEND POWER");
               
               data = ctl.Get_AurPwr();
               
               lpObjectValue[i] = data;              
               lpObjectType[i] = SNMP_INTEGER; 
               
               SetDlgItemInt(hwndMain, IDC_CMDRESPONSE, data, TRUE);

               }

            else if (IsEqual(hinst, IDS_TxAPlateKV, lpObjectId[i]))
               {

   			   SetDlgItemText(hwndMain, IDC_CMDRECEIVED, "GET A PLATE KV");
  			   SetDlgItemText(hwndMain, IDC_CMDEXECUTED, "SEND PLATE KV");
               
               data = ctl.Get_APlateKV();
               
               lpObjectValue[i] = data;              
               lpObjectType[i] = SNMP_INTEGER; 
               
               SetDlgItemInt(hwndMain, IDC_CMDRESPONSE, data, TRUE);

               }

            else if (IsEqual(hinst, IDS_TxBPlateKV, lpObjectId[i]))
               {

   			   SetDlgItemText(hwndMain, IDC_CMDRECEIVED, "GET B PLATE KV");
  			   SetDlgItemText(hwndMain, IDC_CMDEXECUTED, "SEND PLATE KV");
               
               data = ctl.Get_BPlateKV();
               
               lpObjectValue[i] = data;              
               lpObjectType[i] = SNMP_INTEGER; 
               
               SetDlgItemInt(hwndMain, IDC_CMDRESPONSE, data, TRUE);

               }

            else if (IsEqual(hinst, IDS_TxAPlateAmp, lpObjectId[i]))
               {

   			   SetDlgItemText(hwndMain, IDC_CMDRECEIVED, "GET A PLATE AMP");
  			   SetDlgItemText(hwndMain, IDC_CMDEXECUTED, "SEND PLATE AMP");
               
               data = ctl.Get_APlateAmp();
               
               lpObjectValue[i] = data;              
               lpObjectType[i] = SNMP_INTEGER; 
               
               SetDlgItemInt(hwndMain, IDC_CMDRESPONSE, data, TRUE);

               }

            else if (IsEqual(hinst, IDS_TxBPlateAmp, lpObjectId[i]))
               {

   			   SetDlgItemText(hwndMain, IDC_CMDRECEIVED, "GET B PLATE AMP");
  			   SetDlgItemText(hwndMain, IDC_CMDEXECUTED, "SEND PLATE AMP");
               
               data = ctl.Get_BPlateAmp();
               
               lpObjectValue[i] = data;              
               lpObjectType[i] = SNMP_INTEGER; 
               
               SetDlgItemInt(hwndMain, IDC_CMDRESPONSE, data, TRUE);

               }

            }         

         SendGetResponse(lpszRemoteDotAddr, wRemotePort, lpszCommunity, 
               dwRequestId, codeSnmpError, nErrorIndex, nObjects, 
               lpObjectId, lpObjectValue, lpObjectType);
         GlobalFreePtr(lpObjectValue);
         GlobalFreePtr(lpObjectType);
         break; 

//---------------------------------------------------------------------
//  SNMP SET REQUEST Type Message
      
       case SNMP_SET_REQUEST:
         
         for (i = 0; i < nObjects; ++i)
            {
            if (IsEqual(hinst, IDS_TxSysOn, lpObjectId[i])) 
            	{
  			   	SetDlgItemText(hwndMain, IDC_CMDEXECUTED, "PLATE ON");
   			   	SetDlgItemText(hwndMain, IDC_CMDRECEIVED, "SET SYS PWR ON");
               	SetDlgItemText(hwndMain, IDC_CMDRESPONSE, "COMPLETE");

				ctl.Plate_on();
           		}

            else if (IsEqual(hinst, IDS_TxSysOff, lpObjectId[i])) 
            	{
  			   	SetDlgItemText(hwndMain, IDC_CMDEXECUTED, "PLATE OFF");
   			   	SetDlgItemText(hwndMain, IDC_CMDRECEIVED, "SET SYS PWR OFF");
               	SetDlgItemText(hwndMain, IDC_CMDRESPONSE, "COMPLETE");

				ctl.Plate_off();
            	}

            else if (IsEqual(hinst, IDS_TxPowerUp, lpObjectId[i])) 
            	{
  			   	SetDlgItemText(hwndMain, IDC_CMDEXECUTED, "TOGGLE PWR UP");
   			   	SetDlgItemText(hwndMain, IDC_CMDRECEIVED, "SET PWR UP");
               	SetDlgItemText(hwndMain, IDC_CMDRESPONSE, "COMPLETE");

				ctl.Power_up();
            	}

            else if (IsEqual(hinst, IDS_TxPowerDown, lpObjectId[i])) 
            	{
  			   	SetDlgItemText(hwndMain, IDC_CMDEXECUTED, "TOGGLE PWR DOWN");
   			   	SetDlgItemText(hwndMain, IDC_CMDRECEIVED, "SET PWR DOWN");
               	SetDlgItemText(hwndMain, IDC_CMDRESPONSE, "COMPLETE");

				ctl.Power_down();
            	}

            else if (IsEqual(hinst, IDS_TxExciterA, lpObjectId[i])) 
            	{
  			   	SetDlgItemText(hwndMain, IDC_CMDEXECUTED, "GOTO EXC A");
   			   	SetDlgItemText(hwndMain, IDC_CMDRECEIVED, "SET EXC A");
               	SetDlgItemText(hwndMain, IDC_CMDRESPONSE, "COMPLETE");

				ctl.Exciter_a();
            	}

            else if (IsEqual(hinst, IDS_TxExciterB, lpObjectId[i])) 
            	{
  			   	SetDlgItemText(hwndMain, IDC_CMDEXECUTED, "GOTO EXC B");
   			   	SetDlgItemText(hwndMain, IDC_CMDRECEIVED, "SET EXC B");
               	SetDlgItemText(hwndMain, IDC_CMDRESPONSE, "COMPLETE");

				ctl.Exciter_b();
            	}

            else if (IsEqual(hinst, IDS_TxAirA, lpObjectId[i])) 
            	{
  			   	SetDlgItemText(hwndMain, IDC_CMDEXECUTED, "ANT A ON AIR");
   			   	SetDlgItemText(hwndMain, IDC_CMDRECEIVED, "SET AIR A");
               	SetDlgItemText(hwndMain, IDC_CMDRESPONSE, "COMPLETE");

				ctl.Air_a();
            	}

            else if (IsEqual(hinst, IDS_TxAirB, lpObjectId[i])) 
            	{
  			   	SetDlgItemText(hwndMain, IDC_CMDEXECUTED, "ANT B ON AIR");
   			   	SetDlgItemText(hwndMain, IDC_CMDRECEIVED, "SET AIR B");
               	SetDlgItemText(hwndMain, IDC_CMDRESPONSE, "COMPLETE");

				ctl.Air_b();
            	}

            else if (IsEqual(hinst, IDS_TxAirAB, lpObjectId[i])) 
            	{
  			   	SetDlgItemText(hwndMain, IDC_CMDEXECUTED, "BOTH ANTS ON AIR");
   			   	SetDlgItemText(hwndMain, IDC_CMDRECEIVED, "SET AIR AB");
               	SetDlgItemText(hwndMain, IDC_CMDRESPONSE, "COMPLETE");

				ctl.Air_ab();
            	}

            else if (IsEqual(hinst, IDS_TxGenTrans, lpObjectId[i])) 
            	{
  			   	SetDlgItemText(hwndMain, IDC_CMDEXECUTED, "TRANSFER GENERATOR");
   			   	SetDlgItemText(hwndMain, IDC_CMDRECEIVED, "SET GENTRANS");
               	SetDlgItemText(hwndMain, IDC_CMDRESPONSE, "COMPLETE");

				ctl.Gen_transfer();
            	}

            else if (IsEqual(hinst, IDS_TxGenOn, lpObjectId[i])) 
            	{
  			   	SetDlgItemText(hwndMain, IDC_CMDEXECUTED, "GENERATOR ON");
   			   	SetDlgItemText(hwndMain, IDC_CMDRECEIVED, "SET GENON");
               	SetDlgItemText(hwndMain, IDC_CMDRESPONSE, "COMPLETE");

				ctl.Gen_on();
            	}

            else if (IsEqual(hinst, IDS_TxGenOff, lpObjectId[i])) 
            	{
  			   	SetDlgItemText(hwndMain, IDC_CMDEXECUTED, "GENERATOR OFF");
   			   	SetDlgItemText(hwndMain, IDC_CMDRECEIVED, "SET GENOFF");
               	SetDlgItemText(hwndMain, IDC_CMDRESPONSE, "COMPLETE");

				ctl.Gen_off	();
            	}

            }

         SendGetResponse(lpszRemoteDotAddr, wRemotePort, lpszCommunity, 
               dwRequestId, SNMP_NO_ERROR, 0, nObjects, lpObjectId, 
               lpObjectValue, lpObjectType);
         break; 
         
      }
      
   }
   
   
//*************************************************************************
// Display Error Message

void CSnmpAgent::ExceptionEvent(PT_EXCEPTION codeError, 
      LPCSTR lpszErrorDesc)    
   {                                               
   SetDlgItemText(hwndMain, IDC_STATUS, lpszErrorDesc);   
   }
   

//*************************************************************************
//  END OF FILE                              WALT SCHULLER
