// Ccontrol.cpp
//
// Class made from the MarshallSoft toolkit
// Used to control Remote Transmitter Control Unit
// 
// Walter Schuller
// University of North Florida
//  
// Last updated March 97


#include "general.hpp"
#include "calls.hpp"
 
 	int plate_on[] =     {3,0x16,0x41,0x17};
	int plate_off[] =    {3,0x16,0x42,0x14};
	int power_up[] =     {3,0x16,0x43,0x15};
	int power_down[] =   {3,0x16,0x44,0x12};
	int exciter_a[] =    {3,0x16,0x45,0x13};
	int exciter_b[] =    {3,0x16,0x46,0x10};
	int air_a[] =        {3,0x16,0x47,0x11};
	int air_b[] =        {3,0x16,0x48,0x1e};
	int air_ab[] =       {3,0x16,0x49,0x1f};
	int gen_transfer[] = {3,0x16,0x4a,0x1c};
	int gen_on[] =       {3,0x16,0x4b,0x1d};
	int gen_off[] =      {3,0x16,0x4c,0x1a};
	int adc[] =          {3,0x16,0x4d,0x1b};

 
 
//*****************************************************************
// Constructor

Ccontrol::Ccontrol(int v, int w, int x, int y, int z)
	{ 
	Port=v;
	BaudCode=w;
	Parity=x;
	StopBits=y;
	DataBits=z;
	             
	SioParms(Port, Parity, StopBits, DataBits);
	SioReset(Port, 128, 128);               
	SioBaud(Port,BaudCode);  
	
	flag = FALSE;
	}
	


//*****************************************************************
// Destructor

Ccontrol::~Ccontrol()
	{
	SioDone(Port); 
	MessageBeep(-10);
	}
	

//*****************************************************************
// Part of Send Command

 int Ccontrol::send_cmd(int *cmdptr)
 {
	 int i=0, num, count = 0;
	 num = *cmdptr;
	 for (count=1;count<num+1;count++)
		{
		SioPutc(Port,*(cmdptr + count));
		}
//		sleep( (clock_t)1.0 * CLOCKS_PER_SEC );
	
	 return 0;
 }


//*****************************************************************
// PLATE_ON Command

void Ccontrol::Plate_on()
	{
	send_cmd(plate_on);
	}

	
//*****************************************************************
// PLATE_OFF Command

void Ccontrol::Plate_off()
	{
	send_cmd(plate_off);
	}
	

 
//*****************************************************************
// POWER_UP Command

void Ccontrol::Power_up()
	{
	send_cmd(power_up);
	}
	


//*****************************************************************
// POWER_DOWN Command

void Ccontrol::Power_down()
	{
	send_cmd(power_down);
	}

 
//*****************************************************************
// EXCITER_A Command

void Ccontrol::Exciter_a()
	{
	send_cmd(exciter_a);
	}


//*****************************************************************
// EXCITER_B Command

void Ccontrol::Exciter_b()
	{
	send_cmd(exciter_b);
	}
 
 
//*****************************************************************
// AIR_A Command

void Ccontrol::Air_a()
	{
	send_cmd(air_a);
	}


//*****************************************************************
// AIR_B Command

void Ccontrol::Air_b()
	{
	send_cmd(air_b);
	}


//*****************************************************************
// AIR_AB Command

void Ccontrol::Air_ab()
	{
	send_cmd(air_ab);
	}
 
 
//*****************************************************************
// GEN_TRANSFER Command

void Ccontrol::Gen_transfer()
	{
	send_cmd(gen_transfer);
	}



//*****************************************************************
// GEN_ON Command

void Ccontrol::Gen_on()
	{
	send_cmd(gen_on);
	}


//*****************************************************************
// GEN_OFF Command

void Ccontrol::Gen_off()
	{
	send_cmd(gen_off);
	}
 


//*****************************************************************
// Get Visual Power Command

int	Ccontrol::Get_VisPwr()
	{
	if(flag==FALSE)
		Read_data();
	return VisPwr;
	}
	 

//*****************************************************************
// Get Aural Power Command

int	Ccontrol::Get_AurPwr()
	{
	if(flag==FALSE)
		Read_data();
	return AurPwr;
	}


//*****************************************************************
// Get Plate Voltage Command  (A Transmitter)

int	Ccontrol::Get_APlateKV()
	{
	if(flag==FALSE)
		Read_data();
	return APlateKV;
	}



//*****************************************************************
// Get Plate Current Command    (A Transmitter)

int	Ccontrol::Get_APlateAmp()
	{
	if(flag==FALSE)
		Read_data();
	return APlateAmp;
	}



//*****************************************************************
// Get Plate Voltage Command  (B Transmitter)

int	Ccontrol::Get_BPlateKV()
	{
	if(flag==FALSE)
		Read_data();
	return BPlateKV;
	}



//*****************************************************************
// Get Plate Current Command    (B Transmitter)

int	Ccontrol::Get_BPlateAmp()
	{
	if(flag==FALSE)
		Read_data();
	return BPlateAmp;
	}


//*****************************************************************
// Get Spare_1 Command   (Not Used)

int	Ccontrol::Get_Spare1()
	{
	if(flag==FALSE)
		Read_data();
	return Spare1;
	}



//*****************************************************************
// Get Spare_2 Command  (Not Used)

int	Ccontrol::Get_Spare2()
	{
	if(flag==FALSE)
		Read_data();
	return Spare2;
	}


 
   
//*****************************************************************
// Read ADC Data Command

void Ccontrol::Read_data()
	{
	int i=0,j=0,k=0;
	int adc_count=0, value=0; 
	char TempStr[10];
                          
	flag = TRUE;
	                          
	send_cmd(adc);
	delay(3);
	do
		{
		i=SioGetc(Port);
		}
	while ((i>-1)&&(i!=0x02));
	do
		{
		i=SioGetc(Port);
		RecData[k]=i;
		k++;
		}
	while ((i>-1)&&(i!=0x03));
	do
		{
		i=SioGetc(Port);
		}
	while (i>-1);
	
	RecData[k]='\0';
    
// Copy RecData to RxBuf

	lstrcpy(RxBuf, RecData);    
    
// Convert String to Series of Integers

	i=j=0;     
	do
		{
		if ((RecData[i]==0x3a)&&(i<k))
			{
			j=0;
			do
				{
				i++;
				TempStr[j]=RecData[i];   
				j++;
				}
			while (RecData[i]!=0x20);
			TempStr[j]='\0';
			value = atoi(TempStr);       

			switch (adc_count)
				{
				case 0 :	VisPwr = value;
				break;
				case 1 :	AurPwr = value;
				break;
				case 2 :	APlateKV = value;
				break;
				case 3 :	APlateAmp = value;
				break;
				case 4 :	BPlateKV = value;
				break;
				case 5 :	BPlateAmp = value;
				break;
				case 6 :	Spare1 = value;
				break;
				case 7 :	Spare2 = value;
				break;
				}
				
            adc_count++;

			}
		i++;
		}
	while ((i<k)&&(RecData[i]!=0x03));
	
	}

//*****************************************************************
// END OF FILE                        WALT SCHULLER
