// SNMPMP.CPP
//
// Declaration of the Management Windows Program
// Walter Schuller
// University of North Florida
//  
// Last updated March 97
//
// SNMP MANAGER PROGRAM FOR TRANSMITTER CONTROL
//

#include "general.hpp"
#include "calls.hpp"


//*************************************************************************
// Center Window

void CenterWindow(HWND hwnd)
   {
   RECT rc;
   int cx, cy;

   GetWindowRect(hwnd, &rc);
   cx = GetSystemMetrics(SM_CXSCREEN);
   cy = GetSystemMetrics(SM_CYSCREEN);
   
   MoveWindow(hwnd, (cx - rc.right + rc.left) / 2, 
         (cy - rc.bottom + rc.top) / 2,
         rc.right - rc.left, rc.bottom - rc.top, TRUE);  
   }



//*************************************************************************
// Set the background color of the dialog box, buttons controls and 
// static controls to light gray.

HBRUSH AnyWnd_OnCtlColor(HWND hwnd, HDC hdc, HWND hwndChild, int type)
   {
   if (CTLCOLOR_BTN == type || CTLCOLOR_DLG == type || CTLCOLOR_STATIC == type)           
      {                                       
      SetBkMode(hdc, TRANSPARENT);                                               
      return GetStockBrush(LTGRAY_BRUSH);
      }        
      
   return NULL;
   }


//*************************************************************************
// Initialize the Main Window.

BOOL MainWnd_OnInitDialog(HWND hwnd, HWND hwndFocus, LPARAM lParam)
   {                            
   PAPPVARS pav = (PAPPVARS) lParam;  
   LOGFONT logfont;
 	LPFNCTL3DSUBCLASSDLGEX lpfnCtl3dSubclassDlgEx;
   	 
	if ((HINSTANCE) HINSTANCE_ERROR != pav->hinstCtl3d)
		{
		lpfnCtl3dSubclassDlgEx = (LPFNCTL3DSUBCLASSDLGEX)
				GetProcAddress(pav->hinstCtl3d, "Ctl3dSubclassDlgEx");  
		if (lpfnCtl3dSubclassDlgEx)
			(*lpfnCtl3dSubclassDlgEx)(hwnd, 0xffff);		
		}

   CenterWindow(hwnd);          
  
   SetWindowLong(hwnd, GWL_LPAPPVARS, (LONG) (LPAPPVARS) pav);      

   pav->pSnmpManager = new CSnmpManager(GetWindowInstance(hwnd), hwnd);   

   pav->hfontNormal = (HFONT) SendMessage(GetDlgItem(hwnd,
         IDC_SNMPMDESC), WM_GETFONT, 0, 0);

   GetObject(pav->hfontNormal, sizeof(LOGFONT), (LPSTR) &logfont);

   logfont.lfWeight = FW_NORMAL;

   pav->hfontNormal = CreateFontIndirect(&logfont);

   SetDlgItemText(hwnd, IDC_STAT, "Port CLOSED");

 
   // Attempt to Open a UDP Port.
   pav->pSnmpManager->Connect(NULL, PT_NOFLAGS, NULL, 0);
                                             
   return FALSE;
   }


//*************************************************************************
// Process WM_COMMAND Messages for the Main Window.

void MainWnd_OnCommand(HWND hwnd, int id, HWND hwndCtl, UINT codeNotify)
   {  

   HINSTANCE hinst;         
   
   LPSTR lpszObjectId;
   LPSTR lpszObjectValue;
   char szObjectId[64];
   
   SNMP_OBJECT_TYPE fObjectType;      

   	PAPPVARS pav = (PAPPVARS) GetWindowLong(hwnd, GWL_LPAPPVARS);

	hinst = GetWindowInstance(hwnd);            

   switch (id)
      {       
      case IDC_ABOUT:      

			#ifdef WIN32
         	AboutDlg_Do(hwnd, "SNMP C++/32 Class Library");
			#else
         	AboutDlg_Do(hwnd, "SNMP C++/16 Class Library");
			#endif
         break; 

      
      case IDC_PLATE_ON:
         
            fObjectType = SNMP_OCTET_STRING;
            
	        _fstrcpy(szObjectId, GetString(hinst, IDS_TxSysOn));   
                                                 
            lpszObjectId=szObjectId; 
            
            lpszObjectValue = "1";   
            
            pav->pSnmpManager->state = SNMPM_STATE_SETOBJECT;
            
            pav->pSnmpManager->SendSetRequest( 
            pav->pSnmpManager->szRemoteHost, IPPORT_SNMP, "public", 1,
            1, (LPSTR FAR*) &lpszObjectId, (LONG FAR*) &lpszObjectValue, &fObjectType);
         
      	 break;

      case IDC_PLATE_OFF:
         
            fObjectType = SNMP_OCTET_STRING;
            
	        _fstrcpy(szObjectId, GetString(hinst, IDS_TxSysOff));   
                                                 
            lpszObjectId=szObjectId; 
            
            lpszObjectValue = "1";
            
            pav->pSnmpManager->state = SNMPM_STATE_SETOBJECT;
            
            pav->pSnmpManager->SendSetRequest( 
            pav->pSnmpManager->szRemoteHost, IPPORT_SNMP, "public", 1,
            1, (LPSTR FAR*) &lpszObjectId, (LONG FAR*) &lpszObjectValue, &fObjectType);
         
      	 break;

      case IDC_POWER_UP:
         
            fObjectType = SNMP_OCTET_STRING;
            
	        _fstrcpy(szObjectId, GetString(hinst, IDS_TxPowerUp));   
                                                 
            lpszObjectId=szObjectId; 
            
            lpszObjectValue = "1";
            
            pav->pSnmpManager->state = SNMPM_STATE_SETOBJECT;
            
            pav->pSnmpManager->SendSetRequest( 
            pav->pSnmpManager->szRemoteHost, IPPORT_SNMP, "public", 1,
            1, (LPSTR FAR*) &lpszObjectId, (LONG FAR*) &lpszObjectValue, &fObjectType);
         
      	 break;

      case IDC_POWER_DOWN:
         
            fObjectType = SNMP_OCTET_STRING;
            
	        _fstrcpy(szObjectId, GetString(hinst, IDS_TxPowerDown));   
                                                 
            lpszObjectId=szObjectId; 
            
            lpszObjectValue = "1";
            
            pav->pSnmpManager->state = SNMPM_STATE_SETOBJECT;
            
            pav->pSnmpManager->SendSetRequest( 
            pav->pSnmpManager->szRemoteHost, IPPORT_SNMP, "public", 1,
            1, (LPSTR FAR*) &lpszObjectId, (LONG FAR*) &lpszObjectValue, &fObjectType);
         
      	 break;

      case IDC_EXCITER_A:
         
            fObjectType = SNMP_OCTET_STRING;
            
	        _fstrcpy(szObjectId, GetString(hinst, IDS_TxExciterA));   
                                                 
            lpszObjectId=szObjectId; 
            
            lpszObjectValue = "1";
            
            pav->pSnmpManager->state = SNMPM_STATE_SETOBJECT;
            
            pav->pSnmpManager->SendSetRequest( 
            pav->pSnmpManager->szRemoteHost, IPPORT_SNMP, "public", 1,
            1, (LPSTR FAR*) &lpszObjectId, (LONG FAR*) &lpszObjectValue, &fObjectType);
         
      	 break;

      case IDC_EXCITER_B:
         
            fObjectType = SNMP_OCTET_STRING;
            
	        _fstrcpy(szObjectId, GetString(hinst, IDS_TxExciterB));   
                                                 
            lpszObjectId=szObjectId; 
            
            lpszObjectValue = "1";
            
            pav->pSnmpManager->state = SNMPM_STATE_SETOBJECT;
            
            pav->pSnmpManager->SendSetRequest( 
            pav->pSnmpManager->szRemoteHost, IPPORT_SNMP, "public", 1,
            1, (LPSTR FAR*) &lpszObjectId, (LONG FAR*) &lpszObjectValue, &fObjectType);
         
      	 break;

      case IDC_GEN_ON:
         
            fObjectType = SNMP_OCTET_STRING;
            
	        _fstrcpy(szObjectId, GetString(hinst, IDS_TxGenOn));   
                                                 
            lpszObjectId=szObjectId; 
            
            lpszObjectValue = "1";
            
            pav->pSnmpManager->state = SNMPM_STATE_SETOBJECT;
            
            pav->pSnmpManager->SendSetRequest( 
            pav->pSnmpManager->szRemoteHost, IPPORT_SNMP, "public", 1,
            1, (LPSTR FAR*) &lpszObjectId, (LONG FAR*) &lpszObjectValue, &fObjectType);
         
      	 break;

      case IDC_GEN_OFF:
         
            fObjectType = SNMP_OCTET_STRING;
            
	        _fstrcpy(szObjectId, GetString(hinst, IDS_TxGenOff));   
                                                 
            lpszObjectId=szObjectId; 
            
            lpszObjectValue = "1";
            
            pav->pSnmpManager->state = SNMPM_STATE_SETOBJECT;
            
            pav->pSnmpManager->SendSetRequest( 
            pav->pSnmpManager->szRemoteHost, IPPORT_SNMP, "public", 1,
            1, (LPSTR FAR*) &lpszObjectId, (LONG FAR*) &lpszObjectValue, &fObjectType);
         
      	 break;

      case IDC_GEN_TRANS:
         
            fObjectType = SNMP_OCTET_STRING;
            
	        _fstrcpy(szObjectId, GetString(hinst, IDS_TxGenTrans));   
                                                 
            lpszObjectId=szObjectId; 
            
            lpszObjectValue = "1";
            
            pav->pSnmpManager->state = SNMPM_STATE_SETOBJECT;
            
            pav->pSnmpManager->SendSetRequest( 
            pav->pSnmpManager->szRemoteHost, IPPORT_SNMP, "public", 1,
            1, (LPSTR FAR*) &lpszObjectId, (LONG FAR*) &lpszObjectValue, &fObjectType);
         
      	 break;


      case IDC_AIR_A:
         
            fObjectType = SNMP_OCTET_STRING;
            
	        _fstrcpy(szObjectId, GetString(hinst, IDS_TxAirA));   
                                                 
            lpszObjectId=szObjectId; 
            
            lpszObjectValue = "1";
            
            pav->pSnmpManager->state = SNMPM_STATE_SETOBJECT;
            
            pav->pSnmpManager->SendSetRequest( 
            pav->pSnmpManager->szRemoteHost, IPPORT_SNMP, "public", 1,
            1, (LPSTR FAR*) &lpszObjectId, (LONG FAR*) &lpszObjectValue, &fObjectType);
         
      	 break;

      case IDC_AIR_B:
         
            fObjectType = SNMP_OCTET_STRING;
            
	        _fstrcpy(szObjectId, GetString(hinst, IDS_TxAirB));   
                                                 
            lpszObjectId=szObjectId; 
            
            lpszObjectValue = "1";
            
            pav->pSnmpManager->state = SNMPM_STATE_SETOBJECT;
            
            pav->pSnmpManager->SendSetRequest( 
            pav->pSnmpManager->szRemoteHost, IPPORT_SNMP, "public", 1,
            1, (LPSTR FAR*) &lpszObjectId, (LONG FAR*) &lpszObjectValue, &fObjectType);
         
      	 break;

      case IDC_AIR_AB:
         
            fObjectType = SNMP_OCTET_STRING;
            
	        _fstrcpy(szObjectId, GetString(hinst, IDS_TxAirAB));   
                                                 
            lpszObjectId=szObjectId; 
            
            lpszObjectValue = "1";
            
            pav->pSnmpManager->state = SNMPM_STATE_SETOBJECT;
            
            pav->pSnmpManager->SendSetRequest( 
            pav->pSnmpManager->szRemoteHost, IPPORT_SNMP, "public", 1,
            1, (LPSTR FAR*) &lpszObjectId, (LONG FAR*) &lpszObjectValue, &fObjectType);
         
      	 break;

      case IDC_UPDATE:      
      case IDC_HOSTLIST:
      	{                  

         typedef struct tagOBJECTVALUE
               {   
               LPSTR lpszObject[14];
               char szObject[14][24];
               } OBJECTVALUE, FAR *LPOBJECTVALUE;

         LPOBJECTVALUE lpObjectValue;
          
         int i;                      

         lpObjectValue = (LPOBJECTVALUE) GlobalAllocPtr(GPTR, sizeof(OBJECTVALUE)); 
         
         for (i = 0; i < 14; ++i)
             lpObjectValue->lpszObject[i] = &lpObjectValue->szObject[i][0];
            
         i = 0;
         _fstrcpy(lpObjectValue->lpszObject[0], GetString(hinst, IDS_TxVisPwr));    
         _fstrcpy(lpObjectValue->lpszObject[1], GetString(hinst, IDS_TxAurPwr));    
         _fstrcpy(lpObjectValue->lpszObject[2], GetString(hinst, IDS_TxAPlateKV));    
         _fstrcpy(lpObjectValue->lpszObject[3], GetString(hinst, IDS_TxBPlateKV));    
         _fstrcpy(lpObjectValue->lpszObject[4], GetString(hinst, IDS_TxAPlateAmp));    
         _fstrcpy(lpObjectValue->lpszObject[5], GetString(hinst, IDS_TxBPlateAmp));


         ListBox_GetText(hwndCtl, ListBox_GetCurSel(hwndCtl), 
                            pav->pSnmpManager->szRemoteHost);  

         pav->pSnmpManager->state = SNMPM_STATE_QUERYHOST;

         pav->pSnmpManager->SendGetRequest( 
                  pav->pSnmpManager->szRemoteHost, IPPORT_SNMP, "public", 
                  0, 6, (LPSTR FAR*) lpObjectValue);
         
         MessageBeep(-10);
         
         GlobalFreePtr(lpObjectValue);

		}                       
        break;


// Broadcast a Message to Locate Agents

      case IDC_QUERYALLHOSTS:      
         {
         LPCSTR lpObject;

         char szObjectId[] = "1.3.6.1.2.1.1.1.0";         
         lpObject = (LPCSTR) szObjectId;
                  
         pav->pSnmpManager->state = SNMPM_STATE_BROADCAST;
         
         ListBox_ResetContent(GetDlgItem(hwnd, IDC_HOSTLIST)); 

         pav->pSnmpManager->SendGetRequest("255.255.255.255", IPPORT_SNMP, 
               "public", 1, 1, (LPSTR FAR*) &lpObject);
         break;         
         }
         
      } 
       
   }


//*************************************************************************


void MainWnd_OnDestroy(HWND hwnd)
   {
   PAPPVARS pav = (PAPPVARS) GetWindowLong(hwnd, GWL_LPAPPVARS);   

   if (PT_CLOSED != pav->pSnmpManager->State())
      pav->pSnmpManager->Close(TRUE);
   
   delete pav->pSnmpManager;
   
   PostQuitMessage(0);  
   }


//*************************************************************************
// Process Main Window Messages

LRESULT CALLBACK MainWnd_WndProc(HWND hwnd, UINT msg, WPARAM wParam, 
      LPARAM lParam)
   { 
   switch(msg)                     
      {                 
      HANDLE_MSG(hwnd, WM_INITDIALOG, MainWnd_OnInitDialog);   
      HANDLE_MSG(hwnd, WM_COMMAND, MainWnd_OnCommand);   
      HANDLE_MSG(hwnd, WM_DESTROY, MainWnd_OnDestroy);
      
		#ifdef WIN32
      	HANDLE_MSG(hwnd, WM_CTLCOLORBTN, AnyWnd_OnCtlColor);
      	HANDLE_MSG(hwnd, WM_CTLCOLORDLG, AnyWnd_OnCtlColor);
      	HANDLE_MSG(hwnd, WM_CTLCOLORSTATIC, AnyWnd_OnCtlColor);
		#else
      	HANDLE_MSG(hwnd, WM_CTLCOLOR, AnyWnd_OnCtlColor);
		#endif
      }
      
   return DefWindowProc(hwnd, msg, wParam, lParam);
   }                                                                 


//*************************************************************************
// Initialize Application and Establish Message Loop.

int PASCAL WinMain(HINSTANCE hinstCurrent, HINSTANCE hinstPrevious,
      LPSTR lpszCmdLine, int nCmdShow)
   {
   WNDCLASS wndclass;
   HWND hwnd;
   MSG msg;  
   APPVARS av;
   LPFNCTL3DREGISTER lpfnCtl3dRegister;
   LPFNCTL3DAUTOSUBCLASS lpfnCtl3dAutoSubclass;
   
   av.szAppName = "SNMPM";
                                          
	#ifdef WIN32
		av.hinstCtl3d = LoadLibrary("CTL3D32.DLL");
	#else
		av.hinstCtl3d = LoadLibrary("CTL3DV2.DLL");
		if (av.hinstCtl3d < (HINSTANCE) HINSTANCE_ERROR)
			av.hinstCtl3d = LoadLibrary("CTL3D.DLL");
	#endif
	
	if (av.hinstCtl3d >= (HINSTANCE) HINSTANCE_ERROR)
		{  
		lpfnCtl3dRegister = (LPFNCTL3DREGISTER)
				GetProcAddress(av.hinstCtl3d, "Ctl3dRegister");  
		if (lpfnCtl3dRegister)	
			(*lpfnCtl3dRegister)(hinstCurrent);	

		lpfnCtl3dAutoSubclass = (LPFNCTL3DAUTOSUBCLASS)
				GetProcAddress(av.hinstCtl3d, "Ctl3dAutoSubclass");  
		if (lpfnCtl3dAutoSubclass)	
			(*lpfnCtl3dAutoSubclass)(hinstCurrent);	
		}

// Register Main Window Class
   if (!hinstPrevious)
      {
      wndclass.style          = CS_HREDRAW | CS_VREDRAW;
      wndclass.lpfnWndProc    = MainWnd_WndProc;
      wndclass.cbClsExtra     = 0;
      wndclass.cbWndExtra     = MAINWNDEXTRA;
      wndclass.hInstance      = hinstCurrent;
      wndclass.hIcon          = LoadIcon(hinstCurrent, "MAINICON");
      wndclass.hCursor        = LoadCursor(NULL, IDC_ARROW);
      wndclass.hbrBackground  = GetStockBrush(LTGRAY_BRUSH); 
      wndclass.lpszMenuName   = NULL;
      wndclass.lpszClassName  = av.szAppName;    

      RegisterClass(&wndclass);
      }

// Create the Main Window.
   hwnd = CreateDialogParam(hinstCurrent, av.szAppName, 0, 
         (DLGPROC) MainWnd_WndProc, (LPARAM) (LPAPPVARS) &av);
   ShowWindow(hwnd, nCmdShow);
                                              
// Handle Messages 
   while (GetMessage(&msg, NULL, 0, 0))
      if (!IsDialogMessage(hwnd, &msg))
         {
         TranslateMessage(&msg);
         DispatchMessage(&msg);
         }
   
	if (av.hinstCtl3d >= (HINSTANCE) HINSTANCE_ERROR)
		{
		LPFNCTL3DUNREGISTER lpfnCtl3dUnregister;
			
		lpfnCtl3dUnregister = (LPFNCTL3DREGISTER)
				GetProcAddress(av.hinstCtl3d, "Ctl3dUnregister");  
		if (lpfnCtl3dUnregister)	
			(*lpfnCtl3dUnregister)(hinstCurrent);	
		FreeLibrary(av.hinstCtl3d); 
		}

   return msg.wParam;
   }

//**********************************************************************
//  END OF FILE                              WALT SCHULLER
